@@ -8,7 +8,6 @@ MARC::File - Base class for files of MARC records
 
 use strict;
 use integer;
-use MARC::File::Utils;
 
 use vars qw( $ERROR );
 
@@ -19,14 +18,14 @@ use vars qw( $ERROR );
     my $file = MARC::File::USMARC->in( $filename );
 
     while ( my $marc = $file->next() ) {
-        # Do something
+	# Do something
     }
     $file->close();
     undef $file;
 
 =head1 EXPORT
 
-None.
+None.  
 
 =head1 METHODS
 
@@ -37,8 +36,8 @@ or C<MARC::File::MicroLIF> to do this.
 
     my $file = MARC::File::USMARC->in( 'file.marc' );
 
-Returns a C<MARC::File> object, or C<undef> on failure. If you
-encountered an error the error message will be stored in
+Returns a C<MARC::File> object, or C<undef> on failure. If you 
+encountered an error the error message will be stored in 
 C<$MARC::File::ERROR>.
 
 Optionally you can also pass in a filehandle, and C<MARC::File>.
@@ -57,28 +56,27 @@ sub in {
     ## if a valid filehandle was passed in
     my $ishandle = do { no strict; defined fileno($arg); };
     if ( $ishandle ) {
-        $filename = scalar( $arg );
-        $fh = $arg;
+	$filename = scalar( $arg );
+	$fh = $arg;
     }
 
-    ## otherwise check if it's a filename, and
+    ## otherwise check if it's a filename, and 
     ## return undef if we weren't able to open it
     else {
-        $filename = $arg;
-        $fh = eval { local *FH; open( FH, $arg ) or die; *FH{IO}; };
-        if ( $@ ) {
-            $MARC::File::ERROR = "Couldn't open $filename: $@";
-            return;
-        }
-        ## all file streams are assumed to be utf8 if we have a modern perl
+	$filename = $arg;
+	$fh = eval { local *FH; open( FH, $arg ) or die; *FH{IO}; };
+	if ( $@ ) { 
+	    $MARC::File::ERROR = "Couldn't open $filename: $@";
+	    return;
+	}
     }
 
-    utf8_safe() ? binmode( $fh, ':utf8' ) : binmode( $fh );
+    binmode( $fh );
     my $self = {
-        filename    => $filename,
-        fh          => $fh,
-        recnum      => 0,
-        warnings    => [],
+	filename    => $filename, 
+	fh	    => $fh,
+	recnum	    => 0,
+	warnings    => [],
     };
 
     return( bless $self, $class );
@@ -130,7 +128,7 @@ Simlilar to the methods in L<MARC::Record> and L<MARC::Batch>,
 C<warnings()> will return any warnings that have accumulated while
 processing this file; and as a side-effect will clear the warnings buffer.
 
-=cut
+=cut 
 
 sub warnings {
     my $self = shift;
@@ -187,36 +185,23 @@ sub _warn {
 sub _gripe(@) {
     my @parms = @_;
     if ( @parms ) {
-        my $self = shift @parms;
+	my $self = shift @parms;
 
-        if ( ref($self) =~ /^MARC::File/ ) {
-            push( @parms, " at byte ", tell($self->{fh}) )
-                if $self->{fh};
-            push( @parms, " in file ", $self->{filename} ) if $self->{filename};
-        } else {
-            unshift( @parms, $self );
-        }
+	if ( ref($self) =~ /^MARC::File/ ) {
+	    push( @parms, " at byte ", tell($self->{fh}) ) 
+		if $self->{fh};
+	    push( @parms, " in file ", $self->{filename} ) if $self->{filename};
+	} else {
+	    unshift( @parms, $self );
+	}
 
-        $ERROR = join( "", @parms );
-        warn $ERROR;
+	$ERROR = join( "", @parms );
+	warn $ERROR;
     }
 
     return;
 }
 
-=head2 utf8_safe()
-
-Tells whether the version of Perl we're using is UFT8-safe.
-
-=cut
-
-sub utf8_safe {
-    return 0; ## XXX eventually we should be able to handle utf8  
-    return 1 if $] >= 5.008001;
-
-    return 0;
-}
-
 1;
 
 __END__
@@ -239,7 +224,7 @@ We only handle files for input right now.
 
 =head1 LICENSE
 
-This code may be distributed under the same terms as Perl itself.
+This code may be distributed under the same terms as Perl itself. 
 
 Please note that these modules are not products of or supported by the
 employers of the various contributors to the code.
